bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 38. Aventiure
___________________________________________________
| ### <Do> hort man allenthalben iamer also groz ### daz palas vnd tvrne von dem wffe erdoz ### do hort ovch von Berne ein Dieteriches man ### dvrch disiv starchen mære wi balde er gahen began ### Do sprach er zv dem fversten hoert min her Dieterich ### swaz ich noh her gelebt han so rehte vnmvegelich ### gehort ich chlage ni mere als ich nv han vernomen ### ich wæn der chvenech Ecel ist sebe zv dem schaden chomen
###### 2234 | ### Wi moehtens anders alle haben solhen mvt ### der chvenech oder Criemhilt ir einez daz ist tot ### von den chvenen gesten dvrh ir nit gelegen ### ez weinet vngefvge vil manech zierlicher degen
| ### Do sprach der helt von Berne mine vil lieben man ### nv gahet niht ce sere swaz hi hant getan [406b] ### di ellenden recken des gat in michel not ### vnde lat des geniezen daz ich in minen fride enbot
###### 2236 | ### Do sprach <der> chvene Wolfhart ich wil dar gan ### vnde wil vragen der mære waz si hant getan ### vnd wilz iv sagen danne vil lieber herre min ### als ich ez dort ervinde waz div chlage mvge sin
###### 2237 | ### Do sprach der herre Dieterich swa man zorns sich versiht ### ob vngefvgiv vrage danne da gesrhiht ### daz betrvebet lihte den gvten recken ir vil hohen mvt ### iane wil ich niht den Wolfhart daz ir di vrage gein in tvt
| ### Do bat er Helpfrichen vil balde dar gan ### vnd hiez in daz ervinden an Eceln man ### oder an den gesten selben waz wære da geshehen ### done het man von livten so grozen iamer ni gesehen
###### 2239 | ### Der bote begonde vragen waz ist hi getan ### do sprach einer drvnder da ist vil gar cergan ### swaz wir vrevden heten in der Hivnen lant ### hi lit erslagen Rvedeger von der Bvrgonden hant
###### 2240 | ### Di mit im dar in chomen der ist einer niht genesen ### done chonde Helpfriche nimmer leider wesen ### iane gesaget er mære so rehte vngerne nie ### der bote zv Dieteriche vil sere weinende gie
| ### Waz habt ir vns erfvnden sprach do Dieterich ### wi weinet ir so sere degen Helpfrich ### do sprach der edele recke ich mag wol balde chlagen ### den gvten Rvedgeren hant di Bvrgonde erslagen
###### 2242 | ### Do sprach der helt von Berne daz en sol niht wellen got ### daz wære ein starchiv rache vnde ovch des tivels spot ### wa mit het Rvedger an in daz versolt ### ia ist mir daz wol chvende er ist den ellenden holt
###### 2243 | ### des antwrte Wolfhart vnde [407a] heten siz getan ### so solt ez in allen an ir lebn gan ### ob wirz in vertrvegen des wære wir geschant ### ia hat vns vil gedienet des gvten Rvedgeres hant
| ### Der vogt der Amelvnge hiez ez ervinden baz ### vil harte snellechlice er in <ein> venster saz ### do bat er Hildebranden zv den gesten gan ### daz er an in erfvende waz da wære getan
###### 2245 | ### Der stvrmchvene reche meister Hildbrant ### weder schilt noch waffen trvg er an der hant ### er wolde in sinen zvehten zv den gesten gan ### von swester chinde wart im ein straffen getan
###### 2246 | ### Do sprach der grimme Wolfhart welt ir dar blozer gan ### so mag er an ein schelten nimmer wol gesten ### so mvezet ir lasterlichen tvn di widervart ### chvmt ir dar gewaffent daz etelicher wol bewart
| ### Do garte sich der wise dvrch des tvmben rat ### ê daz ers innen wrde do warn in ir wat ### alle Dieteriches recken vnt trvgen swert en hant ### dem helde was leide vil gerne het erz erwant
###### 2248 | ### Er vragte war si wolden wir wellen mit iv dar ### waz ob von Tronege Hagene deste wirs gevar ### gein iv mit spotte sprechen des er wol chan pflegen ### do er daz gehorte da von gestattes in der degen
###### 2249 | ### Do sach der chvene Wolker wol gewaffent gan ### di recken von Berne di Dieteriches man ### begvertet mit den swerten si trvgen schilt enhant ### er sagetez sinem herren vzer Bvrgonden lant
| ### Do sprach der videlære ich sihe dort her gan ### so rehte vientliche di Dieteriches man ### gewaffent vnder helme si wellent vns bestan ### ich wæn ez an daz vebele welle vns ellenden gan
###### 2251 | ### In den selben ziten chom ovch [407b] Hildebrant ### do satzet er fver di fveze sines schildes rant ### er begonde vragen di Gvntheres man ### owe ir gvten helde waz het iv Rvedger getan
###### 2252 | ### Mich hat min herre Dieterich her zv ziv gesant ### ob erslagen hete iwer deheines hant ### den edeln margraven als vns daz ist geseit ### wirn chvnden veberwinden niht div grozlichen leit
| ### Do sprach von Tronege Hagene daz mære ist vngelogen ### wi wol ich iv des gvnde het iv der bote betrogen ### dvrch Rvedegeres liebe daz noch lebte sin lip ### den immer mvgen weinen beide man vnd ovch div wip
###### 2254 | ### Do si daz rehte erhorten daz er wære tot ### do chlageten in di recken ir triwe in daz gebot ### den Dieteriches recken sach man træhne gan ### veber berte vnde vber chinne in was vil leide getan
###### 2255 | ### Der herzoge von Berne ce Sigestap do sprach ### nv hat gar ein ende genomen der gemach ### den vns ie gefvgete Rvdeger nach vnser leide tagen ### vroevde ellender diete lit an Rvedger erslagen
| ### Do sprach von Amelvngen der degen Wolfin ### vnd ob ich hivte sæhe tot den vater min ### mir enwrde nimmer leider danne vmbe sinen lip ### owe wer sol nv troesten des edeln margraven wip
###### 2257 | ### Do sprach in zornes mvote der degen Wolfhart ### wer wiset nv di recken so manege herewart ### also der margrave vil diche hat getan ### owe vil edel Rvedeger daz wir dich svs verlorn han
###### 2258 | ### Wolfprant vnd Hepfrich vnd ovch Helmnot ### mit allen ir vrivnden chlagten sinen tot ### vor svften mohte vragen niht mere Hildebrant ### er sprach nv tvt ir degene dar nach min herre hat gesant [408a]
| ### Gebt vns Rvedgern also toten vz dem sal ### an dem gar mit iamer lit vnser vrevden val ### lat vns an im dienen daz er ie hat began ### an vns vil groze triwe vns an manegem andern man
###### 2260 | ### Wir sind ovch ellende als Rvedger der degen ### wes lazet ir uns pitet lat in vns after wægen ### tragen daz wir nach tode lonen noch dem man ### wir hetenz pilliche bi sime lebene getan
###### 2261 | ### Do sprach der kvenech Gventher ni dienest wart so gvt ### so den ein vrivnt vrivnde nach dem tode tvt ### daz heiz ich stæte triwe der di chan began ### ir lonet im nach schvlden er hat iv liebes vil getan
| ### Wi lange svln wir vlegen sprach Wolfhart <der> degen ### sit vnser trost der beste von iv ist tot gelegen ### vnd wir sin leider mere mvegen niht gehaben ### laten vns hinnen tragen daz wir den recken begraben
###### 2263 | ### Des antwrte Volker niemen in iv git ### nemten in dem hvse da der degen lit ### mit starch verchwnden gevallen in daz plvt ### so ist ez ein voller dienest den ir Rvedgeren tvt
###### 2264 | ### Do sprach der chvene Wolfhart got weiz her spilman ### iren dverffet vns niht reizen ir habt vns leit getan ### getorst ich vor minem herren so choemet irs in not ### des mvezen wirz lazen wand er vns striten hi verbot
| ### Do sprach der videlære der vorhte ist gar ce vil ### swaz man im verbivtet derz allez wil ### daz chan ich niht geheizen rehten heldes mvt ### div rede duhte Hagenen uon sinem hergesellen gvt
###### 2266 | ### <· Desen> lat iuch niht <belangen> sprach aber Wolfhart ### ich entrihte iv so di seiten swenne ir di wideruart ### ritet gein dem Rine daz irz uuol muget sagen ### iuuer vebermueten mag ich mit eren niht vertragen
###### 2267 | ### Do sprach der uidelære swenne ir [408b] di seiten min ### verirret guter doene der iuuer helme schin ### der muz uil truebe uuerden von der minen hant ### suui halt ich gerite in der Buergonden lant
| ### Do uuold er zv zim springen wande daz in niht enlie ### Hildebrant sin oeheim in uaste zim gevie ### ich wæne du woldest toben durch den tumben zorn ### mines herren hulde hetes du immer mer verlorn
###### 2269 | ### Lat abe den lewen meister er ist so grimmer gemut ### chumt aber er mir cen handen sprach Volker der degen gut ### het er di uuerlt alle mit siner hant erslagen ### ich slahe in daz erz uuiderspel nimmer mer darf gesagen
###### 2270 | ### Des wart uil harte erzvernet der Bernære mut ### den schilt gezvchte Wolfhart ein sneller degen gut ### alsam ein lev wilder lief er uor in dan ### im wart ein gahez volgen uon sinen vriunden getan
| ### Swi witer sprunge er pflæge fver des sales want ### doch ergahte in vor der stiege der alte Hildebrant ### eren wolde in uor im lazen niht chomen in den strit ### si funden daz si suchten an den ellenden sit
###### 2272 | ### Do gespranch zv Hagenen meister Hildebrant ### diu swert man horte erchlingen an ir beider hant ### si waren ser erzvernet daz mohte man chiesen sint ### von ir zweier swerten gie fiwer roter wint
###### 2273 | ### Di wrden do gescheiden in des sturmes not ### daz taten di uon Berne als in ir chrapft gebot ### zehant do wande Hildebrant uon Hagenen wider dan ### do lief der starche Wolfhart den chvenen Volkeren an
| ### Er sluch den uidelære vf den helm gut ### daz des swertes ecke vnz an di spangen wt ### daz vergalt mit ellen der chuene spilman ### so slug er Wolfharten daz er stieben <began>
###### 2275 | ### Des fiwers vz den ringen hiwen si genuch ### haz ir iegelicher dem andern da truch ### di shiet do von [409a] Berne der degen Wolfin ### ob ez ein helt niht wære desen chunde niht gesin
###### 2276 | ### Guenther der recke mit uil willeger hant ### enpfie di helde mære von Amelunge lant ### Giselher der herre diu liehten helmvaz ### der frumt er da uil manigez uon plvote unde naz
| ### Danchwart Hagen bruder was ein grimmech man ### swaz er da uor hete in strite ie getan ### den Eceln recken daz was gar ein wint ### nu uaht uil tobeliche des chuenen Aldrianes chint
###### 2278 | ### Ritschart unde Gerbart Helpfrich unde Wichart ### di heten in manegn sturmen uil selten sich gespart ### des brahten si wol innen di Guentheres man ### do sach man Wolfranden in strite herliche gan
###### 2279 | ### Do uaht alsma er wote der alte Hildebrant ### uil der guten recken uor Wolfhartes hant ### mit tode musen uallen uon swerten in daz pluot ### sus rachen Ruedgeren di recken chuene unde gut
| ### Do uaht der herre Sigestap als im sin ellen riet ### hey waz er in dem strite guter helme uerschriet ### den sinen uianden Dieteriches swester sun ### eren chunde in dem sturme nimmer bezzers niht getun
###### 2281 | ### Uolker der starche do er daz ersach ### daz Sigestap der chuene den bluotegen bach ### hiu uzzer herten ringen daz was dem helde zorn ### er spranch im hin engegene do het Sigestap uerlorn
###### 2282 | ### von dem uidelære uil schiere da daz sin leben ### er begonde im siner chvenste alsolhen teil da geben ### daz er uon sinem swerte muose liegen tot ### daz rach der alte Hildebrant als im sin ellen daz gebot
| ### Owe liebes herren sprach meister Hildebrant ### der hi lit erstorben uon Volkeres hant ### nu sol der uidelære langer niht genesen ### Hildebrant der chuene wi chund er grimmer gewesen
###### 2284 | ### Do sluch er Volkeren daz im div [409b] helmbant ### stuben allenthalben zu des sals want ### uon helm vnd ouch uon schilde dem chuenen spileman ### da uon der starche Volker do den ende da gewan
###### 2285 | ### Do drungen zu dem strite di Dieteriches man ### si slugen daz di ringe uil uerre dræten dan ### unt daz man ort der swerte uil hohe uliegen sach ### si holten uz den helmen den hieze uliezenden bach
| ### Do sach uon Tronege Hagene Volkeren tot ### daz was cer hohgezite sin aller meistiv not ### di er da hete gewnnen an magen und ouch an man ### owe wi harte Hagene den helt do rechen began
###### 2287 | ### Nune sol es niht geniezen der alte Hildebrant ### min helfe lit erslagen uon des heldes hant ### der beste hergeselle den ich ie gewan ### den schilt er ruchte hoher do gi er howende dan
###### 2288 | ### Helpfrich der chuene Danchwarten sluch ### Guenthere unde Giselhere den was ez leit genuch ### do si in uallen sahen in der starchen not ### er hete mit sinen handen uil wol uergolten sinen tot
| ### Di wile gie do Wolfhart beide wider unde dan ### allez howende di Guentheres man ### er was di driten chere chomen durch den sal ### da uiel uon sinen handen uil manech recke ce tal
###### 2290 | ### Do rief der herre Giselher Wolfharten an ### owe daz ich so grimmen uient ie gewan ### edel ritter chuene nu wendet gegen in ### ich wilz helfen enden ezen mag niht lenger gesin
###### 2291 | ### Zv Giselhere cherte <Wolfhart> in den strit ### do sluch ietwederr uil manege wnden wit ### so rehte krepftechlichen er zv dem kvenege dranch ### daz imez pluot under fuezen al ueber daz houbet spranch
| ### Mit swinden slegen grimme der schonen Vten chint ### enpfie er Wolfharten den chvenen helt sint ### swi starch der degen wære [410a] ern chunde niht genesen ### ezen dorfte kvenech so iunger nimmer chuener gewesen
###### 2293 | ### Do sluch er Wolfharten durch eine brvenne gvt ### daz im uon der wnden nider uloz daz pluot ### er wnte zu dem tode den Dieteriches man ### ezen het an einen recken zware niemen getan
###### 2294 | ### Also der chuene Wolfhart der wnden do enpfant ### den schilt den liez er uallen hoher an der hant ### hub er ein starchez waffen daz was starch genuch ### durch helm unt durch ringe der helt do Giselheren sluch
| ### Si heten beide ein ander den grimmen tot getan ### done lebte ouch niht mere der Dieteriches man ### Hildebrant der alte Wolfharten uallen sach ### im wæne vor sinem tode so rehte leide ni geschach
###### 2296 | ### Do waren gar erstorben di Guentheres man ### vnd ouch di Dieteriches Hildebrant was gegan ### da Wolfhart was gevallen nider in daz plut ### er besloz mit armen den recken chvene vnde gut
###### 2297 | ### Er wolden uzem huse mit im tragen dan ### er was ein teil ce swære er muse in ligen lan ### do blichte ouch <vz> dem bluote der rewende man ### er sach wol daz im gerne sin neve het geholffen dan
| ### Do sprach der totwnde vil lieber oheim min ### ir muegt an disen ziten mir niht frvm gesin ### nv hvetet iuch vor Hagenen ia dunchet ez mich gut ### er treit in sinem hercen einen grimmigen mvt
###### 2299 | ### Vnde ob mich mine mage nach tode wellen chlagen ### den næhestn vnt den besten den sult ir von mir sagen ### daz si nach mir niht weinen daz ist ane not ### uor eines kveneges handen lige ich hi herlichen tot
###### 2300 | ### Ich han ouch so vergolten hirinne minen lip ### daz ez wol mvgen beweinen der guten ritter wip ### ob iuch des iemen vrage so muegt ir balde sagen ### vor min eines [410b] handen ligent wol hundert erslagen
| ### Do gedaht ovch Hagen an den spileman ### dem der chvne Hildebrant sin leben an gewan ### do sprach er zv dem degene ir geltet miniv leit ### ir habt vns hinne enbunden vil maneges recken gemeit
###### 2302 | ### Er sluch vf Hildebranden daz man wol vernam ### Balmvngen diezen den Sifride nam ### Hagen der chvene da er den helt ersluch ### do werte sich der alte ia was er chvene genuch
###### 2303 | ### Der recke Dieteriches sluch ein waffen breit ### vf den helt von Tronege daz ovch vil sere sneit ### done chunder niht verwnden den Guentheres man ### do sluoch aber in Hagene durch eine brvenne wol getan
| ### Do der alte Hildebrant der wnden enpfant ### do uorhte er schaden mere von der Hagenen hant ### den schilt warf veber ruke der Dieteriches man ### mit der starchen wnden der helt do Hagenen entran
###### 2305 | ### Da was niemen lebende aller der degene ### niwan di einen zwene Guenther vnd Hagene ### mit bluote gie bervnnen der alte Hildebrant ### er brahte leidiv mære da er Dieterichen vant
###### 2306 | ### Do sah er trvrechliche sitzen hi den man ### der leide michel mere der fverste do gewan ### er sah ouch Hildebranden in siner brvenne rot ### do vragete er der mære als im div sorge gebot
| ### Nv sagt mir meister Hildebrant wi sit ir so naz ### von dem verchpluote oder wer tet iv daz ### ich wæne ir mit den gesten zem huse habt gestriten ### ich verbot ez iv so sere ir hetez pilliche vermiten
###### 2308 | ### Do sagt er sinem herren ez tet Hagene ### der slug mir dise wnden in dem gademe ### do ich von dem recken wolde wenden dan ### mit dem minem lebene ich dem tivfel vil chvme entran [411a]
###### 2309 | ### Do sprach der Bernære vil rehte ist iv geschehen ### do ir mich frivntschepfte den recken hortet gehen ### daz ir den vride brachet den ich in hete gegeben ### het iches niht immer shande ir soldet vliesen daz leben
| ### Nv zvernet niht so sere min her Dieterich ### an mir vnd minen frivnden der schade ist al ce rich ### wir wolden Rvedgeren getragen haben dan ### desen wolden vns niht gunnen des chvnech Gventheres man
###### 2311 | ### So we mir dirre leide ist Ruedeger doch tot ### daz mvz mir sin ein iamer vor aller miner not ### Goetelint div edele ist miner pasen chint ### âch we der armen weisen di da ce Bechlaren sint
###### 2312 | ### Triwen vnde leides mant mich sin tot ### er begonde starche weinen des gie dem helde not ### owe getriwer helfe di ich verlon han ### iane veberwinde ich nimmer des chvenech Eceln man
| ### Mveget ir mir meister Hildebrant div mære rehte sagen ### wer der recke wære der in da habe erslagen ### er sprach daz tet mit chrepften der starche Gernot ### vor Ruedgeres henden ist ouch der helt gelegen tot
###### 2314 | ### Er sprach ce Hildebrande nv sagt minen man ### daz si sich palde waffen wand ich wil dar gan ### vnde heizet mir gewinnen min liehtez wichgewant ### ich wil selbe vragen di helde vzer Burgonden lant
###### 2315 | ### Do sprach meister Hildebrant wer sol zv ziv gen ### swaz ir habt der lebenden di seht ir hi bi iv sten ### daz pin ich alterseine di andern di sint tot ### do erschract er dirre mære des gie im wærliche not
| ### Wand er leit so grozez cer werld nie gewan ### er sprach vnde sint erstorben alle mine man ### so hat min got vergezzen ich armer Dieterich ### ich was ein chvnech here vil gewaltech vnd rich
###### 2317 | ### Wi chvnde ez sich gefvegen sprah her Dieterich ### daz si alle sint [411b] erstorben di helde lobelich ### von den stritmueden di doch heten not ### wande durch min vngeluecke in wære vremde noch der tot
###### 2318 | ### Sit daz ez min vnschulde niht langer wolde entwesen ### so sagt mir ist den geste noch iemen genesen ### do sprach meister Hildebrant daz weiz got niemen mer ### niwan Hagen aleine vnde Guenther der kvenech her
| ### Owe lieber Wolfhart sol ich dich han verlorn ### so mag mich balde riwen daz ich ie wart geborn ### Sygestap vnd Wolfwin vnd ouch Wolfprant ### wer sol mir danne helffen in der Amelunge lant
###### 2320 | ### Helpfrich der vil chvene vnd ist mir der erslagen ### Gerbart vnd Wichart wi solde ich di uerchlagen ### daz ist an minen vrevden mir der leste tach ### owe daz vor leide niemen sterbene mach

<<< Übersicht <<< vorige Seite nächste Seite >>>